@@ -2,9 +2,8 @@
 
 from typing import Optional
 
-from pydantic import BaseModel
-
 from ...store_type import StoreType
+from ..base_model import BaseModel
 
 
 class UserIncome(BaseModel):
